"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.privateApi = void 0;

var _constants = _interopRequireDefault(require("./constants"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// constants

/**
 * Utils service that prepares plugin options.
 * Contains methods that help with defaults and constructing options that can be used by the plugin.
 *
 * @private
 * @mixin
 */
var privateApi = {};
/**
 * Prepare options for the plugin.
 * Contains methods that help with defaults and constructing options that can be used by the plugin.
 *
 * @mixin
 */

exports.privateApi = privateApi;
var service = {};
/**
 * Get regular expression based on provided matcher
 *
 * @private
 *
 * @param {String|Array<String>} matcher - string or array with strings based on which regular expression is created
 * @param {String} matcherName - name of the property
 * @param {Array<String>} defaultMatcher - default value for matcher
 *
 * @return {RegExp|Error} regular expression or exception
 */

privateApi.getMatcher = function (matcher, matcherName) {
  var defaultMatcher = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  var matcherForRegExp;

  if (matcher) {
    var matcherAsArray = Array.isArray(matcher);

    if (matcherAsArray) {
      var validMatcher = matcher.filter(Boolean).map(function (stringMatcher) {
        return "(".concat(stringMatcher, ")");
      });
      matcherForRegExp = validMatcher.join('|');
    } else if (typeof matcher === 'string') {
      matcherForRegExp = matcher;
    } else {
      throw new Error("[babel-auto-logger-plugin] '".concat(matcherName, "' can be string or array with strings"));
    }
  } else {
    // use default
    matcherForRegExp = defaultMatcher.map(function (stringMatcher) {
      return "(".concat(stringMatcher, ")");
    }).join('|');
  }

  return new RegExp(matcherForRegExp);
};
/**
 * Get default value for sourceMatcher.
 *
 * @private
 * @default
 *
 * @return {Array<String>} defaultSourceMatcher
 */


privateApi.getSourceMatcher = function () {
  return ['.*js(x)?$'];
};
/**
 * Get default value for sourceExcludeMatcher.
 *
 * @private
 * @default
 *
 * @return {Array<String>} defaultSourceExcludeMatcher
 */


privateApi.getSourceExcludeMatcher = function () {
  return ['__fixtures__', '__mocks__', '__tests__', '__snapshots__', 'node_modules'];
};
/**
 * Get supported log levels by the plugin
 *
 * @private
 * @default
 *
 * @return {Array<String>} defaultLogLevels
 */


privateApi.getSupportedLogLevels = function () {
  return ['debug', 'error', 'info', 'log', 'warn'];
};
/**
 * Prepare logging level settings.
 *
 * @private
 *
 * @param {String} logLevel - log level
 * @param {LoggerLevelObj} logLevelData - logging level options
 * @return {Object} options - object with options for the provided log level
 */


privateApi.getLogLevelData = function (logLevel, logLevelData) {
  var options = {}; // log level method name (property from logger that is a function)
  // if is not provided will use logLevel

  options.methodName = logLevelData.methodName || logLevel; // TODO: source matching & method name matching for this level of logging (next version)

  return options;
};
/**
 * Prepare logging levels.
 * It will check every log level and prepared settings for it.
 *
 * @private
 *
 * @param {Object} loggingLevels - logging levels
 * @return {Object} options - object with options got the logging levels
 */


privateApi.getLoggingLevels = function (loggingLevels) {
  var options = {};
  var supportedLogLevels = privateApi.getSupportedLogLevels();
  supportedLogLevels.forEach(function (logLevel) {
    var logLevelData = loggingLevels && loggingLevels[logLevel] || {};
    options[logLevel] = privateApi.getLogLevelData(logLevel, logLevelData);
  });
  return options;
};
/**
 * Prepare options for the logger.
 * It will set the source, name, map for levels
 *
 * @private
 *
 * @param {LoggerDataObj} loggingData - logging data
 * @return {Object} options - object with options for logging data
 */


privateApi.getLoggingData = function (loggingData) {
  var options = {};

  var _ref = loggingData || {},
      levels = _ref.levels,
      name = _ref.name,
      source = _ref.source;

  options.name = name || _constants.default.LOGGER_API;

  if (options.name === _constants.default.LOGGER_API) {
    // when we are using default, we shouldn't have source
    options.source = '';
  } else {
    options.source = source || '';
  }

  options.levels = privateApi.getLoggingLevels(levels);
  return options;
};
/**
 * Prepare options for the plugin
 *
 * @param {Object} receivedOptions - object with options (state.opts)
 * @param {String} [receivedOptions.sourceMatcher] - matcher for the files where logger will be added. This string will be used as argument for `new RegExp`
 * @param {String} [receivedOptions.sourceExcludeMatcher] - matcher for the files where logger should not be add. This string will be used as argument for `new RegExp`
 * @param {Object} [receivedOptions.loggingData] - object with data for the logger (source, name, levels, map for levels)
 * @return {Object} options - object with options for the plugin
 */


service.prepare = function (receivedOptions) {
  var options = {}; // source matcher
  // if we do not receive value for `sourceMatcher` add empty string by default (will match everything)

  options.sourceMatcher = privateApi.getMatcher(receivedOptions.sourceMatcher, 'sourceMatcher', privateApi.getSourceMatcher()); // source exclusion matcher
  // if we do not receive value for sourceExcludeMatcher use default (see privateApi.getSourceExcludeMatcher)

  options.sourceExcludeMatcher = privateApi.getMatcher(receivedOptions.sourceExcludeMatcher, 'sourceExcludeMatcher', privateApi.getSourceExcludeMatcher()); // logging data

  options.loggingData = privateApi.getLoggingData(receivedOptions.loggingData);
  return options;
}; // only for testing


var _default = service;
exports.default = _default;